==> aria2_1.15.1.orig.tar.bz2: aria2-1.15.1/src/UnknownOptionException.h <==
/* <!-- copyright */
/*
 * aria2 - The high speed download utility
 *
 * Copyright (C) 2011 Tatsuhiro Tsujikawa
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 *
 * In addition, as a special exception, the copyright holders give
 * permission to link the code of portions of this program with the
 * OpenSSL library under certain conditions as described in each
 * individual source file, and distribute linked combinations
 * including the two.
 * You must obey the GNU General Public License in all respects
 * for all of the code used other than OpenSSL.  If you modify
 * file(s) with this exception, you may extend this exception to your
 * version of the file(s), but you are not obligated to do so.  If you
 * do not wish to do so, delete this exception statement from your
 * version.  If you delete this exception statement from all source
 * files in the program, then also delete it here.
 */
/* copyright --> */
#ifndef D_UNKNOWN_OPTION_EXCEPTION_H
#define D_UNKNOWN_OPTION_EXCEPTION_H
#include "RecoverableException.h"

namespace aria2 {

class UnknownOptionException:public RecoverableException {
private:
  std::string unknownOption_;
protected:
  virtual SharedHandle<Exception> copy() const;
public:
  UnknownOptionException(const char* file, int line,
                         const std::string& unknownOption);

  UnknownOptionException(const char* file, int line,
                         const std::string& unknownOption,
                         const Exception& cause);

  virtual ~UnknownOptionException() throw();

  const std::string& getUnknownOption() const
  {
    return unknownOption_;
  }
};

#define UNKNOWN_OPTION_EXCEPTION(arg)                   \
  UnknownOptionException(__FILE__, __LINE__, arg)
#define UNKNOWN_OPTION_EXCEPTION2(arg1, arg2)                   \
  UnknownOptionException(__FILE__, __LINE__, arg1, arg2)

} // namespace aria2

#endif // D_UNKNOWN_OPTION_EXCEPTION_EX_H

==> aria2_1.18.8.orig.tar.bz2: aria2-1.18.8/src/UnknownOptionException.h <==
/* <!-- copyright */
/*
 * aria2 - The high speed download utility
 *
 * Copyright (C) 2011 Tatsuhiro Tsujikawa
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 *
 * In addition, as a special exception, the copyright holders give
 * permission to link the code of portions of this program with the
 * OpenSSL library under certain conditions as described in each
 * individual source file, and distribute linked combinations
 * including the two.
 * You must obey the GNU General Public License in all respects
 * for all of the code used other than OpenSSL.  If you modify
 * file(s) with this exception, you may extend this exception to your
 * version of the file(s), but you are not obligated to do so.  If you
 * do not wish to do so, delete this exception statement from your
 * version.  If you delete this exception statement from all source
 * files in the program, then also delete it here.
 */
/* copyright --> */
#ifndef D_UNKNOWN_OPTION_EXCEPTION_H
#define D_UNKNOWN_OPTION_EXCEPTION_H
#include "RecoverableException.h"

namespace aria2 {

class UnknownOptionException:public RecoverableException {
private:
  std::string unknownOption_;
protected:
  virtual std::shared_ptr<Exception> copy() const CXX11_OVERRIDE;
public:
  UnknownOptionException(const char* file, int line,
                         const std::string& unknownOption);

  UnknownOptionException(const char* file, int line,
                         const std::string& unknownOption,
                         const Exception& cause);

  virtual ~UnknownOptionException() throw();

  const std::string& getUnknownOption() const
  {
    return unknownOption_;
  }
};

#define UNKNOWN_OPTION_EXCEPTION(arg)                   \
  UnknownOptionException(__FILE__, __LINE__, arg)
#define UNKNOWN_OPTION_EXCEPTION2(arg1, arg2)                   \
  UnknownOptionException(__FILE__, __LINE__, arg1, arg2)

} // namespace aria2

#endif // D_UNKNOWN_OPTION_EXCEPTION_EX_H
